@@ -1,6 +1,7 @@
 import unittest
-from pyserver_client.server import Server, ExecuteCommandError
+from pyserver_client.server import RemoteServer, ExecuteCommandError
 from tempfile import TemporaryFile, TemporaryDirectory
+from pyserver_client.base import ResultPresentation, ExecuteResult
 import os
 import re
 
@@ -30,10 +31,11 @@ class TestServices(unittest.TestCase):
 
     def test_01_welcome(self):
         target = "/tmp/hello_world.txt"
-        with Server(Config.SERVER_IP, Config.SERVER_USER, port=Config.SERVER_PORT,
-                    password=Config.SERVER_PASSWORD) as server:
-            response = server.shell('echo "Welcome ${USER}!"')
-            self.assertEqual([f'Welcome {Config.SERVER_USER}!\n'], response.rows)
+        with RemoteServer(Config.SERVER_IP, Config.SERVER_USER, port=Config.SERVER_PORT,
+                    password=Config.SERVER_PASSWORD, exec_result=ExecuteResult) as server:
+            exec_result = server.shell('echo "Welcome ${USER}!"')
+            presentation = ResultPresentation(exec_result)
+            self.assertEqual([f'Welcome {Config.SERVER_USER}!\n'], presentation.rows)
 
             # with TemporaryFile() as temp:
             #     byte_text = b"Create temp file.\n"
@@ -57,8 +59,8 @@ class TestServices(unittest.TestCase):
             #     self.assertEqual(1, res.return_code())
 
     def test_02_struct_shell(self):
-        with Server(Config.SERVER_IP, Config.SERVER_USER, port=Config.SERVER_PORT,
-                    password=Config.SERVER_PASSWORD) as server:
+        with RemoteServer(Config.SERVER_IP, Config.SERVER_USER, port=Config.SERVER_PORT,
+                    password=Config.SERVER_PASSWORD, exec_result=ExecuteResult) as server:
             server.struct_shell("ls -la")
             with self.assertRaises(ExecuteCommandError):
                 server.struct_shell("ldasds -la")
